import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class CodeView extends StatefulWidget {
  final String code;
  final Color? backgroundColor;
  final Color? textColor;
  final String title;

  const CodeView({
    Key? key,
    required this.code,
    this.backgroundColor,
    this.textColor,
    required this.title,
  }) : super(key: key);

  @override
  State<CodeView> createState() => _CodeViewState();
}

class _CodeViewState extends State<CodeView> {
  @override
  Widget build(BuildContext context) {
    return Container(
      clipBehavior: Clip.antiAlias,
      padding: const EdgeInsets.all(10),
      decoration: BoxDecoration(
        color: widget.backgroundColor ?? Colors.blue,
      ),
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                widget.title,
                style: TextStyle(color: widget.textColor),
              ),
              IconButton(
                icon: Icon(
                  Icons.copy,
                  color: widget.textColor ?? Colors.white,
                ),
                onPressed: () {
                  Clipboard.setData(ClipboardData(text: widget.code));
                  ScaffoldMessenger.of(context).hideCurrentSnackBar();
                  ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
                      behavior: SnackBarBehavior.floating,
                      content: Text("Copied")));
                },
              ),
            ],
          ),
          Divider(
            color: widget.textColor,
          ),
          SelectableText(
            widget.code,
            style: TextStyle(color: widget.textColor ?? Colors.white),
          ),
        ],
      ),
    );
  }
}
